@@ -12,18 +12,14 @@ class SDTicketCollection(SDFirstClassCollection):
         self._all_tickets = None
 
     def get_with_sd_id(self, ticket_id):
-        for ticket in self.all:
-            if ticket.ticket_id == ticket_id:
-                return ticket
-        else:
-            return None
+
+        return SDTicket(parent=self, location=self.location, ticket_id=ticket_id)
 
     def get_with_pos_id(self, pos_ticket_id):
-        for ticket in self.all:
-            if ticket.pos_ticket_id == pos_ticket_id:
-                return ticket
-        else:
-            return None
+        swagger_ticket = self._swagger_locations_api.getTicketWithPOS_ID(location_id=self.location.location_id,
+                                                                         pos_ticket_id=pos_ticket_id, api_key=self._api_key)
+
+        return SDTicket(parent=self, location=self.location, ticket_id=swagger_ticket.ticket_id)
 
     def refresh(self):
         self._swagger_tickets = self._swagger_locations_api.getTickets(location_id=self.location.location_id,
